@@ -7,7 +7,7 @@
 # reserved. This program is free software; you can redistribute it and/or
 # modify it under the same terms as Perl itself.
 #
-# $Id: Received.pm,v 1.19 2000/04/27 00:09:22 adam Exp $
+# $Id: Received.pm,v 1.23 2000/04/28 19:58:12 adam Exp $
 #
 
 require 5.005;
@@ -23,7 +23,7 @@ use vars qw($VERSION @ISA @EXPORT_OK);
 @ISA = qw(Exporter Mail::Field Mail::Field::Generic);
 @EXPORT_OK = qw(%RC &diagnose);
 
-$VERSION = '0.22';
+$VERSION = '0.23';
 
 =head1 NAME
 
@@ -263,9 +263,7 @@ sub parse {
         if ($last_section eq 'from') {
          FROMCOMMENT:
           {
-            if ($comment =~ 
-#                            /()($RC{domain})\s+\[($RC{ipv4_addr})\]/)
-                            /\(
+            if ($comment =~ /\(
                                 (?:(?:($RC{local_part})\@)?($RC{domain})\s+)?
                                 (?:\[ $RC{ipv4_addr} \])(?:
                             )\)/x)
@@ -293,21 +291,21 @@ sub parse {
 
             if ($comment =~ /(HELO|EHLO)\s+($RC{domain})/) {
               # HELO domain is in comments, not outside, so swap
-              $self->diagnose("Got $1 domain in comments: $2\n")
+              $self->diagnose("Got `from' $1 domain in comments: $2\n")
                 if $debug >= 3;
               @{$parsed{from}}{qw/domain HELO/}
                 = ($parsed{from}{HELO}, $2);
             }
 
             if ($comment =~ /$RC{ipv4_addr}\]?(?::(\d{1,5}))?/) {
-              $self->diagnose("Got IP address in comments: $1\n")
+              $self->diagnose("Got `from' IP address in comments: $1\n")
                 if $debug >= 3;
 
               $parsed{from}{address} = $1;
 
               if ($2) {
                 $parsed{from}{port} = $2;
-                $self->diagnose("Got port in comments: $1\n")
+                $self->diagnose("Got `from' port in comments: $1\n")
                   if $debug >= 3;
               }
             }
@@ -354,7 +352,7 @@ sub parse {
         next TOKEN;
       }
       
-      if ($expecting{after_from} and /\G$RC{domain_lit}/cg) {
+      if ($expecting{after_from} and /\G($RC{domain_lit})/cg) {
         $self->diagnose("Got address from bad `from': $1\n") if $debug >= 3;
         $parsed{from}{address} = $1;
         delete $expecting{after_from};
@@ -400,7 +398,7 @@ sub parse {
         next TOKEN;
       }
 
-      if ($expecting{after_by} and /\G$RC{domain_lit}/cg) {
+      if ($expecting{after_by} and /\G($RC{domain_lit})/cg) {
         $self->diagnose("Got address from bad `by': $1\n") if $debug >= 3;
         $parsed{by}{address} = $1;
         delete $expecting{after_by};
@@ -513,7 +511,7 @@ sub parse {
         }
 
         if ($parsed{with}{with} eq 'WorldClient' and
-            /\G$RC{domain_lit}/cg) {
+            /\G($RC{domain_lit})/cg) {
           $self->diagnose("Got WorldClient address from bad `with': $1\n")
             if $debug >= 3;
           delete $expecting{after_with};
@@ -705,7 +703,10 @@ like:
   {
    'by' => {
             'domain' => 'host5.hostingcheck.com',
-            'whole' => 'by host5.hostingcheck.com'
+            'whole' => 'by host5.hostingcheck.com',
+            'comments' => [
+                           '(8.9.3/8.9.3)'
+                          ],
            },
    'date_time' => {
                    'year' => 2000,
@@ -728,14 +729,13 @@ like:
              },
    'from' => {
               'domain' => 'mediacons.tecc.co.uk',
-              'HELO' => undef,
+              'HELO' => 'tr909.mediaconsult.com',
+              'from' => 'tr909.mediaconsult.com',
               'address' => '193.128.6.132',
               'comments' => [
                              '(mediacons.tecc.co.uk [193.128.6.132])',
-                             '(8.9.3/8.9.3)',
                             ],
               'whole' => 'from tr909.mediaconsult.com (mediacons.tecc.co.uk [193.128.6.132])
- (8
 '  
              },
    'id' => {
